@@ -174,8 +174,8 @@ impl std::fmt::Display for FinalWithTone {
             NonRhoticFinal::In => ("i", "n"),
             NonRhoticFinal::Ing => ("i", "ng"),
             NonRhoticFinal::Iong => ("io", "ng"),
-            NonRhoticFinal::Iu => ("i", "u"),
-            NonRhoticFinal::Io => ("i", "o"),
+            NonRhoticFinal::Iu => ("iu", ""),
+            NonRhoticFinal::Io => ("io", ""),
             NonRhoticFinal::O => ("o", ""),
             NonRhoticFinal::Ong => ("o", "ng"),
             NonRhoticFinal::Ou => ("o", "u"),
